%SCRIPT FILE TO PLOT THE BOUNDING FORECAST DISTRIBUTIONS IN FIGURE 3,
%[BOUNDING FORECAST DISTRIBUTIONS WITH THE LARGEST AND SMALLEST DEGREES OF PERSISTENCE]


...........................................................................
...........................................................................

clear all

...........................................................................
...........................................................................


%//////////////////////////////////////////////////////////////////////////
%TO INITIALIZE THE RANDOM NUMBER GENERATORS TO A DIFFERENT STATE
%//////////////////////////////////////////////////////////////////////////

...........................................................................
    

%Reset the global random number stream to its initial settings.
s = RandStream('mt19937ar','Seed',9);
RandStream.setGlobalStream(s);
...........................................................................
...........................................................................


%//////////////////////////////////////////////////////////////////////////
%INITIALIZING
%//////////////////////////////////////////////////////////////////////////

%topdir = 'Output\';

global T 
T = 100;   %Number of obsrvations in a generated sample,

...........................................................................                        

beta_M = 0.6; %The true AR parameter in the DGP

%NOTE: DGP: Y_t = beta_M Y_{t-1} + e_t, where e_t iid N(0,1) to generate
%(Y_0, ..., Y_{T-1}), T-sample size 
...........................................................................

%//////////////////////////////////////////////////////////////////////////
%TO GENERATE THE MAIN SAMPLE (Y_0, ..., Y_{T-1}) FROM 
%DGP: Y_t = beta_M Y_{t-1} + e_t, where e_t iid N(0,1)
%//////////////////////////////////////////////////////////////////////////

%To draw (T+30) errors from a N(0,1) distribution

  e_M = normrnd(0,1,1,T+30);
    
%To compute the corresponding Y_T values Y_T(1-30,u),...,Y_T(T,u) w.r.t. 
%(NOTE: We set the initial value Y_T(-30)=0)
   
    Y = zeros(1,T+31);
    
%    Y(1)= 0;   

Y(1) = normrnd(0,1.25); %Stationary distribution of Y(t); N(0,1.25^2)
    
    for i=1:(T+30)
        Y(i+1) = beta_M*Y(i) + e_M(i);
    end
    
    Y_T_M = Y(31:T+30)'; %First 30 observations is omited to mitigate the 
                      %initial effects and T = length(Y_T_M)
    c = Y_T_M;                  

%Treat the vector 'c' as a drawn sample from an AR(1) model
%where the error distribution and AR parameters are
%unknown and use the LS metod to compute a residual vector 'h_e_M' and 
%centered scalled residuals 'ti_e_M' which consistently estimate the 
%unknown errors.

%To specify an AR(1) model with no constant term and an unknown AR
%parameter (coefficient)

model_ar = arima(1,0,0);
model_ar.Constant = 0;

%To fit the AR(1) model in model_ar to series c and obtain residuals and
%estimated parameters

fit = estimate(model_ar,c); %Fit model_ar to series c

h_beta_M = cell2mat(fit.AR); %AR(1) coefficient of the fitted model

h_var_M = fit.Variance; %estimated error variance of the fitted model

h_e_M = c(2:T) - h_beta_M*c(1:T-1); %estimated forward residuals

%centered scaled forward residuals

ti_e_M = sqrt((T-1)/(T-2))*(h_e_M - mean(h_e_M)); 

ti_Y_M = ti_e_M + h_beta_M*c(T); %\wh F_{Y_T}(x) =(T-1)\sum(ti_Y =< x)

exp_Y_M = h_beta_M*c(T); %Expected value of Y_T

%sti_Y_M = sort(ti_Y_M);

%Rti_Y_M = sort(ti_Y_M);

hat_Y_T = beta_M*c(T); %True Expected value of Y_T

x_T = linspace(hat_Y_T-4,hat_Y_T+4,T);

Rti_Y_M = x_T;

%Rti_Y_M is the sorted values of ti_Y_M

F_N_M = normcdf(Rti_Y_M-h_beta_M*c(T)); %Y_T_M cdf, \h F_{Y_T_M}, values at sti_Y_M

F_N_M_pdf = normpdf(Rti_Y_M-h_beta_M*c(T)); %Y_T_M pdf, \h f_{Y_T_M}, values at sti_Y_M

F_N_T = normcdf(Rti_Y_M-beta_M*c(T)); %Y_T_M cdf, \h F_{Y_T_M}, values at sti_Y_M

F_N_T_pdf = normpdf(Rti_Y_M-beta_M*c(T)); %Y_T_M pdf, \h f_{Y_T_M}, values at sti_Y_M



%%%%%%%%%%%
%For the case : variance unknown
%%%%%%%%%%%

%%%%%%%%
%Bounding distribution with maximum/minimum mean
%%%%%%%%

sig2_m = fminsearch (@(th) -(5.9915-(T/2)*((h_var_M-th)/th)^2)*th/sum(c.^2), 0);

beta_max = h_beta_M + sqrt((5.9915-(T/2)*((h_var_M-sig2_m)/sig2_m)^2)*sig2_m/sum(c.^2));

beta_min = h_beta_M - sqrt((5.9915-(T/2)*((h_var_M-sig2_m)/sig2_m)^2)*sig2_m/sum(c.^2));


%For the bounding distribution with maximum mean:

F_N_2_pdf = normpdf((Rti_Y_M-beta_max*c(T))/sqrt(sig2_m)); 


%For the bounding distribution with minimum mean:

F_N_2m_pdf = normpdf((Rti_Y_M-beta_min*c(T))/sqrt(sig2_m)); 


%Plots of bounding densities with largest/smallest mean

x_e = Rti_Y_M;


plot(x_e,F_N_M_pdf,':black',...
     x_e,F_N_2_pdf,'-.black',...
     x_e,F_N_2m_pdf,'--black','LineWidth',2)
                 
ylabel('f(Y_{T+1} | y_{1:T}, \theta)','fontsize',16); 
xlabel('Y_{T+1}','fontsize',16); 
legend ('Empirical', 'Largest mean', 'Smallest mean');

%end

..........................................................................

...........................................................................                        



 
