#setwd("C:/Users/.../Final_JGCS")
setwd("C:/Users/iperera/Documents/my_files/Don-Gael/tex/With-david/draft paper/New_draft/JGCS_resub/code-rb")

set.seed(42)
library(animation)
library(graphics)

mixedN.p <- function(x){
  (1-p1f.p)*dnorm(x, mean=mu0hat.p, sd=sd.p)+p1f.p*dnorm(x, mean=mu1hat.p, sd=sd.p)
}

mixedN <- function(x){
  (1-p1f)*dnorm(x, mean=mu0hat, sd=sd)+p1f*dnorm(x, mean=mu1hat, sd=sd)
}

T <- 100

d <- numeric(length=T)
y <- numeric(length=T)

#p11 = Pr[d(t)=1|d(t-1)=1), p00 = Pr[d(t)=0|d(t-1)=0)

p11 <- 0.6
p00 <- 0.6

mu1 <- 3
sig1 <- 1

mu0 <- 0
sig0 <- 1

#runif(1) generates a random number on [0,1], hence d[t] has a binomial dist with success prob Pr1 for each t
#Since numeric(length=T) creates a zero vector of length T, the following loop starts with d[0]=0.

for (t in 2:T){
  Pr1 <- (1-p00) + (p11+p00-1)*d[t-1]
  d[t] <- 1*(runif(1)<Pr1)
}

#Command 'ts' generates a time series 

mu <- d*mu1 + (1-d)*mu0
sig <- d*sig1 + (1-d)*sig0
y <- ts(rnorm(T, mu, sig))
d <- ts(d)

plot(density(y))
plot(y)
acf(y)

dat <- ts.intersect(y, y1=lag(y), d, d1=lag(d), dframe=TRUE)
eq1 <- lm(y~0+d+I(1-d), dat)
V1 <- vcov(eq1)
ehat <- eq1$residuals
s2 <- mean(ehat^2)
vs2 <- var(ehat^2)/T
mu1hat <- eq1$coefficients[1]
mu0hat <- eq1$coefficients[2]

eq2 <- lm(d~0+d1+I(1-d1), dat)
V2 <- vcov(eq2)

p1f <- d[T]*eq2$coefficients[1]+(1-d[T])*eq2$coefficients[2]
vp1f <- V2[2-d[T], 2-d[T]]

bhat <- rbind(mu1hat, mu0hat, s2, p1f)

sd <- sqrt(s2)
curve(mixedN, from=(mu0hat.p-4*sd), to=(mu1hat.p+4*sd))


V <- cbind(V1, matrix(0, nrow=2, ncol=2))
V <- rbind(V, cbind(matrix(0, nrow=1, ncol=2), vs2, 0))
V <- rbind(V, cbind(matrix(0, nrow=1, ncol=3), vp1f))

k <- nrow(V)
cv <- qchisq(0.95, df=k)
eig <- eigen(solve(V)/cv)
V2i <- eig$vectors %*% sqrt(diag(1/eig$values)) 

n <- 6
x1 <- (0:(n-1))/n*pi
x2 <- (0:(n-1))/n*(2*pi)

theta <- matrix(0, nrow=n^k, ncol=k)
b <- theta
x <- 1:k
r <- 1
for (j1 in 1:n){
  for (j2 in 1:n){
    for (j3 in 1:n){
      for (j4 in 1:n){
        theta[r,1] <- x1[j1]
        theta[r,2] <- x1[j2]
        theta[r,3] <- x1[j3]
        theta[r,4] <- x2[j4]
        x[1] <- cos(theta[r,1])
        x[2] <- sin(theta[r,1])*cos(theta[r,2])
        x[3] <- sin(theta[r,1])*sin(theta[r,2])*cos(theta[r,3])
        x[4] <- sin(theta[r,1])*sin(theta[r,2])*sin(theta[r,3])*cos(theta[r,4])
        b[r,] <- t(V2i %*% x)
        r <- r+1
      }
    }
  }
}
b <- unique(b)

composite.expression <- expression(paste("f(", Y[T+1], " | ", theta, ", ", H[T], " )"))


#Static Plots

# Specify the file name.
pdf("mixNplotstex_w6n4-n2_stat_rb.pdf",width=8,height=5)

cl <- rainbow(12)

for (k in 1:12){
	r <- k*50
    sd.p <- sqrt(s2-b[r,3])
    mu0hat.p <- mu0hat-b[r,2]
    mu1hat.p <- mu1hat-b[r,1]
    p1f.p <- p1f-b[r,4]
    curve(mixedN.p, from=(mu0hat-4*sd), to=(mu1hat+4*sd), n=501, xlab=expression(Y[T+1]), ylab=composite.expression, ylim = c(0,0.4), main="", col = cl[k], cex.lab=1.18)
    curve(mixedN, from=(mu0hat-4*sd), to=(mu1hat+4*sd), n=501, ylim = c(0,0.4), add=TRUE, lty = 3, lwd = 2)    
    par(new = TRUE)
	}

# Save the file.
dev.off()



