%SCRIPT FILE TO GENERATE THE DATA FILES REQUIRED FOR THE R PROGRAMS BASED 
%ON MODEL M2.
%
%OUTPUT: DATA FILES 'toR_egAR_modC762.mat' AND 'Main_emp_annual_AR_modCT762.mat'

...........................................................................
...........................................................................

clear all

load rt_rv_bv

n = 762; % [Sep 14, 2005 to Sep 23, 2008] n+1: Sep 24, 2008 (r_{n+1}=-0.654717919  V_{n+1}=0.064473071)

r_T_M = Returnsdaily(2389:2389+(n-1)); %2389+(n-1)=3150 [Sep 14, 2005 to Sep 23, 2008] (3150=sep 23/08, 3151=n+1=sep 24/08)

v_T_M = RV(2389:2389+(n-1));

logv_T_M = log(v_T_M);

...........................................................................
...........................................................................

%//////////////////////////////////////////////////////////////////////////
%INITIALIZING
%//////////////////////////////////////////////////////////////////////////

global T 
T = n;   %number of obsrvations in the observed sample

initial_theta = [0 0.4 -0.2 0.4 0.05 2.5]'; 

x_data = zeros(2*T,1);

x_data_M = zeros(2*T,1);

...........................................................................   

%Computation of the asymptotic MLE covariance matrix    

x_data_M(1:T) = r_T_M;
  
x_data_M(T+1:2*T) = logv_T_M;

h_theta_M = mle(x_data_M,'pdf',@npdf5,'start',initial_theta);

cov_theta_npdf_M = mlecov(h_theta_M,x_data_M,'pdf',@npdf5);

h_mu1 = h_theta_M(1);
h_mu2 = h_theta_M(2);
h_om = h_theta_M(3);
h_phi1 = h_theta_M(4);
h_gam = h_theta_M(5);
h_sig2 = h_theta_M(6);

b_t = zeros(1,T+1);

b_t(1) = h_om;

b_t(2) = h_om + h_phi1*x_data_M(T+1) + h_gam*((x_data_M(1)- h_mu1)/sqrt(exp(b_t(1)+abs(h_sig2)/2)));

for i=2:T
  b_t(i+1) = h_om + h_phi1*x_data_M(T+i) + h_gam*((x_data_M(i)- h_mu1 - h_mu2*x_data_M(i-1))/sqrt(exp(b_t(i)+abs(h_sig2)/2)));
end

beta_t = b_t(1:T);

sigmasq_t = exp(beta_t'+ abs(h_sig2)/2);

u_M = zeros(1,T);

u_M(1) = (x_data_M(1)-h_mu1)/sqrt(sigmasq_t(1));

u_M(2:T) = (x_data_M(2:T)- h_mu1 - h_mu2*x_data_M(1:T-1))./sqrt(sigmasq_t(2:T));


%Computation of the L_T matrix $L_T = [\dell_{T+1} \hat{V}_{T}(\hat{\theta})\dell_{T+1})']^{-1}$

dell_th = [1 r_T_M(T) 0 0 0 0; 0 0 1 logv_T_M(T) u_M(T) 0; 0 0 0 0 0 1];

ell_T_M = dell_th*cov_theta_npdf_M*dell_th';

ell_T_inv = inv(ell_T_M);

beta_T = b_t(T+1);

h_mu_T = h_mu1 + h_mu2*x_data_M(T);

sigmasq_T = exp(beta_T'+ abs(h_sig2)/2);

...........................................................................

%//////////////////////////////////////////////////////////////////////////
%Computation of the bounding set at the 95% level
%//////////////////////////////////////////////////////////////////////////

obs_last_val = logv_T_M(T); %For the conditional wald method we need the 
                            %observed value $\cV_T$.

asy_cv = chi2inv(0.95,3); %Upper 95% quantile of the asymptotic chi2(3) distribution (the
                          %limiting distribution of the Wald statistic). This equals 7.8147

%Wald(th) = (hth - th)'*(acov\(hth - th));
%Bounding distributions are obtained by the set \{th : Wald(th)=asy_cv\}
%We want to find a grid of points on the ellipsoid
%(th-hth)'*A_M*(th-hth) = 1, A_M = ell_T_inv/asy_cv;

A_M = ell_T_inv/asy_cv;

eig_val = eig(A_M); %Eigenvalues of A_M

ax_a = 1/sqrt(eig_val(1));  ax_b = 1/sqrt(eig_val(2));  ax_c = 1/sqrt(eig_val(3)); 

n_s = 20;

[x, y, z] = ellipsoid(h_mu_T,beta_T,h_sig2,ax_a,ax_b,ax_c,n_s);

% figure
% surf(x, y, z)
% axis equal

obs_nxt_rT = Returnsannual(2389+n);

obs_nxt_RV = RV(2389+n);


save(['Main_emp_annual_AR_modC','T',int2str(T)]);


save(['toR_egAR_modC',int2str(T)],'h_*','obs_*','T','beta_T','x','y','z');


..........................................................................

...........................................................................                        


 
